#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernires rvisions       : 10/10/2008
#
#package			: openarena
#homepage			: http://openarena.ws/?
#source location	: http://download.tuxfamily.org/openarena/rel/080/oa080.zip

softnamesrc='oa081'
softname='openarena'
softversion='0.8.1'
packageversion='54.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation fate pour PII et >
#
arch='i686'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# log
#
(

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations  la fois
#
# numjobs='-j6'
#
# "lger" PC: 2 compilations  la fois
#
numjobs='-j2'

#
# paramtres pour compiler
#
buildir=$(pwd)
srcpkg="$buildir/$softnamesrc.zip"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://download.tuxfamily.org/openarena/rel/081/$softnamesrc.zip
sourceicon=http://www.opensource4mac.de/img/spiele/ioquake3_icon.png

#
# preparer le rpertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/$softname
mkdir -p $dest/usr/share/$softname/baseoa
mkdir -p $dest/usr/share/$softname/missionpack
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc
         |-----handy-ruler------------------------------------------------------|
openarena: openarena - first person shooter like Quake III Arena
openarena:
openarena: OpenArena is an open-source content package for Quake III Arena  
openarena: licensed under the GPL, effectively creating a free stand-alone game.
openarena: You do not need Quake III Arena to play this game.
openarena: 
openarena: 
openarena:
openarena: 
openarena:
openarena: 
EOF

#
# Verifie si package est present
#
if [ -f $softnamesrc.zip ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
unzip $srcpkg -d $buildir
cd $src

#
# "faire" le package package
#
cp -a openarena.i386 $dest/usr/share/$softname
cp -a baseoa/*.pk3 $dest/usr/share/$softname/baseoa
cp -a missionpack/*.pk3 $dest/usr/share/$softname/missionpack
chmod 755 $dest/usr/share/$softname/openarena.i386
chmod 644 $dest/usr/share/openarena/baseoa/*

#
# "faire" icon
#
wget -c $sourceicon
mv ioquake3_icon.png openarena.png
convert openarena.png -resize 48x48 openarena.png 
cp openarena.png  $dest/usr/share/icons/hicolor/48x48/apps

# "faire" .desktop
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Openarena
Comment=A first person shooter
Exec=openarena
Icon=openarena
Terminal=false
Type=Application
Categories=Game;ActionGame;
Encoding=UTF-8
EOF

cat <<EOF > $dest/usr/bin/openarena
#!/bin/sh
exec /usr/share/openarena/openarena.i386 "\$@"
EOF

chmod 755 $dest/usr/bin/openarena

#
# ajout des fichiers de docs, infos, ...
#
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      CHANGES COPYING CREDITS LINUXNOTES README OGGVORBIS.README.txt SDL.README.txt\
      $dest/usr/doc/$softname-$softversion
    chmod 644 $dest/usr/doc/$softname-$softversion/*

#
# Mettre le zenbuild  sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.tgz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.tgz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "cxxlibs,directfb,expat,freetype,gcc,gcc-g++,gdbm,fontconfig,libdrm,libjpeg,\
libogg,libpng,libtiff,libvorbis,libmikmod,mesa,ncurses,openal,openssl,perl,sdl,sysfsutils,xorg,zlib" > $package.dep

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# produire le fichier src
#
echo http://users.zenwalk.org/user-accounts/bip/EXTRA/games/openarena/source/build-openarena.sh > $package.src
echo $sourceicon >> $package.src
echo $source >> $package.src


#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
